stat

package
v0.0.0-...-fa6965a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 21, 2019 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Stater

type Stater struct {
	// contains filtered or unexported fields
}

func New

func New(checkContent bool) *Stater

func (*Stater) Stat

func (s *Stater) Stat(root string, expr string) (hash []byte, err error)

Stat creates a hash of all the files given by expr (using root), either by using contents of files or only the mod-time. TODO: include a ref to cache so we can write for each individual file

Jump to